@@ -1,6 +1,10 @@
 #' Summarise multiple columns
 #'
 #' @description
+#' \Sexpr[results=rd, stage=render]{lifecycle::badge("superseded")}
+#'
+#' Scoped verbs (`_if`, `_at`, `_all`) have been superseded by the use of
+#' [across()] in an existing verb. See `vignette("colwise")` for details.
 #'
 #' The [scoped] variants of [summarise()] make it easy to apply the same
 #' transformation to multiple variables.
@@ -38,7 +42,7 @@
 #'
 #'   ```
 #'   nms <- setdiff(nms, group_vars(data))
-#'   data %>% summarise_at(vars, myoperation)
+#'   data %>% summarise_at(nms, myoperation)
 #'   ```
 #'
 #' * Grouping variables covered by implicit selections are silently
@@ -46,80 +50,88 @@
 #'
 #' @section Naming:
 #'
-#' The names of the created columns is derived from the names of the
+#' The names of the new columns are derived from the names of the
 #' input variables and the names of the functions.
 #'
-#' - if there is only one unnamed function, the names of the input variables
-#'   are used to name the created columns
+#' - if there is only one unnamed function (i.e. if `.funs` is an unnamed list
+#'   of length one),
+#'   the names of the input variables are used to name the new columns;
 #'
-#' - if there is only one unnamed variable, the names of the functions
-#'   are used to name the created columns.
+#' - for `_at` functions, if there is only one unnamed variable (i.e.,
+#'   if `.vars` is of the form `vars(a_single_column)`) and `.funs` has length
+#'   greater than one,
+#'   the names of the functions are used to name the new columns;
 #'
-#' - otherwise in the most general case, the created names are created by
-#'   concatenating the names of the input variables and the names of the functions.
+#' - otherwise, the new names are created by
+#'   concatenating the names of the input variables and the names of the
+#'   functions, separated with an underscore `"_"`.
 #'
-#' The names of the functions here means the names of the list of functions
-#' that is supplied. When needed and not supplied, the name of a function
-#' is the prefix "fn" followed by the index of this function within the
-#' unnamed functions in the list. Ultimately, names are made
-#' unique.
+#' The `.funs` argument can be a named or unnamed list.
+#' If a function is unnamed and the name cannot be derived automatically,
+#' a name of the form "fn#" is used.
+#' Similarly, [vars()] accepts named and unnamed arguments.
+#' If a variable in `.vars` is named, a new column by that name will be created.
+#'
+#' Name collisions in the new columns are disambiguated using a unique suffix.
+#'
+#' @section Life cycle:
+#'
+#' The functions are maturing, because the naming scheme and the
+#' disambiguation algorithm are subject to change in dplyr 0.9.0.
 #'
 #' @examples
-#' by_species <- iris %>%
-#'   group_by(Species)
-#'
-#'
 #' # The _at() variants directly support strings:
 #' starwars %>%
 #'   summarise_at(c("height", "mass"), mean, na.rm = TRUE)
+#' # ->
+#' starwars %>% summarise(across(c("height", "mass"), ~ mean(.x, na.rm = TRUE)))
 #'
 #' # You can also supply selection helpers to _at() functions but you have
 #' # to quote them with vars():
 #' starwars %>%
 #'   summarise_at(vars(height:mass), mean, na.rm = TRUE)
+#' # ->
+#' starwars %>%
+#'   summarise(across(height:mass, ~ mean(.x, na.rm = TRUE)))
 #'
 #' # The _if() variants apply a predicate function (a function that
 #' # returns TRUE or FALSE) to determine the relevant subset of
 #' # columns. Here we apply mean() to the numeric columns:
 #' starwars %>%
 #'   summarise_if(is.numeric, mean, na.rm = TRUE)
+#' starwars %>%
+#'   summarise(across(where(is.numeric), ~ mean(.x, na.rm = TRUE)))
+#'
+#' by_species <- iris %>%
+#'   group_by(Species)
 #'
 #' # If you want to apply multiple transformations, pass a list of
 #' # functions. When there are multiple functions, they create new
 #' # variables instead of modifying the variables in place:
 #' by_species %>%
 #'   summarise_all(list(min, max))
-#'
-#' # Note how the new variables include the function name, in order to
-#' # keep things distinct. Passing purrr-style lambdas often creates
-#' # better default names:
+#' # ->
 #' by_species %>%
-#'   summarise_all(list(~min(.), ~max(.)))
-#'
-#' # When that's not good enough, you can also supply the names explicitly:
-#' by_species %>%
-#'   summarise_all(list(min = min, max = max))
-#'
-#' # When there's only one function in the list, it modifies existing
-#' # variables in place. Give it a name to create new variables instead:
-#' by_species %>% summarise_all(list(med = median))
-#' by_species %>% summarise_all(list(Q3 = quantile), probs = 0.75)
+#'   summarise(across(everything(), list(min = min, max = max)))
 #' @export
 summarise_all <- function(.tbl, .funs, ...) {
-  funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ...)
+  lifecycle::signal_superseded("1.0.0", "summarise_all()", "across()")
+  funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ..., .caller = "summarise_all")
   summarise(.tbl, !!!funs)
 }
 #' @rdname summarise_all
 #' @export
 summarise_if <- function(.tbl, .predicate, .funs, ...) {
-  funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), ...)
+  lifecycle::signal_superseded("1.0.0", "summarise_if()", "across()")
+  funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), ..., .caller = "summarise_if")
   summarise(.tbl, !!!funs)
 }
 #' @rdname summarise_all
 #' @export
 summarise_at <- function(.tbl, .vars, .funs, ..., .cols = NULL) {
+  lifecycle::signal_superseded("1.0.0", "summarise_at()", "across()")
   .vars <- check_dot_cols(.vars, .cols)
-  funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), ...)
+  funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), ..., .caller = "summarise_at")
   summarise(.tbl, !!!funs)
 }
 
@@ -136,6 +148,10 @@ summarize_at <- summarise_at
 #' Mutate multiple columns
 #'
 #' @description
+#' \Sexpr[results=rd, stage=render]{lifecycle::badge("superseded")}
+#'
+#' Scoped verbs (`_if`, `_at`, `_all`) have been superseded by the use of
+#' [across()] in an existing verb. See `vignette("colwise")` for details.
 #'
 #' The [scoped] variants of [mutate()] and [transmute()] make it easy to apply
 #' the same transformation to multiple variables. There are three variants:
@@ -177,6 +193,7 @@ summarize_at <- summarise_at
 #'   `transmute_if()`.
 #'
 #' @inheritSection summarise_all Naming
+#' @inheritSection summarise_all Life cycle
 #'
 #' @examples
 #' iris <- as_tibble(iris)
@@ -186,27 +203,33 @@ summarize_at <- summarise_at
 #' # we'll scale the variables `height` and `mass`:
 #' scale2 <- function(x, na.rm = FALSE) (x - mean(x, na.rm = na.rm)) / sd(x, na.rm)
 #' starwars %>% mutate_at(c("height", "mass"), scale2)
+#' # ->
+#' starwars %>% mutate(across(c("height", "mass"), scale2))
 #'
 #' # You can pass additional arguments to the function:
 #' starwars %>% mutate_at(c("height", "mass"), scale2, na.rm = TRUE)
-#'
-#' # You can also pass formulas to create functions on the spot, purrr-style:
 #' starwars %>% mutate_at(c("height", "mass"), ~scale2(., na.rm = TRUE))
+#' # ->
+#' starwars %>% mutate(across(c("height", "mass"), ~ scale2(.x, na.rm = TRUE)))
 #'
 #' # You can also supply selection helpers to _at() functions but you have
 #' # to quote them with vars():
 #' iris %>% mutate_at(vars(matches("Sepal")), log)
+#' iris %>% mutate(across(matches("Sepal"), log))
 #'
 #' # The _if() variants apply a predicate function (a function that
 #' # returns TRUE or FALSE) to determine the relevant subset of
 #' # columns. Here we divide all the numeric columns by 100:
 #' starwars %>% mutate_if(is.numeric, scale2, na.rm = TRUE)
+#' starwars %>% mutate(across(where(is.numeric), ~ scale2(.x, na.rm = TRUE)))
 #'
 #' # mutate_if() is particularly useful for transforming variables from
 #' # one type to another
 #' iris %>% mutate_if(is.factor, as.character)
 #' iris %>% mutate_if(is.double, as.integer)
-#'
+#' # ->
+#' iris %>% mutate(across(where(is.factor), as.character))
+#' iris %>% mutate(across(where(is.double), as.integer))
 #'
 #' # Multiple transformations ----------------------------------------
 #'
@@ -214,14 +237,12 @@ summarize_at <- summarise_at
 #' # functions. When there are multiple functions, they create new
 #' # variables instead of modifying the variables in place:
 #' iris %>% mutate_if(is.numeric, list(scale2, log))
-#'
-#' # The list can contain purrr-style formulas:
 #' iris %>% mutate_if(is.numeric, list(~scale2(.), ~log(.)))
-#'
-#' # Note how the new variables include the function name, in order to
-#' # keep things distinct. The default names are not always helpful
-#' # but you can also supply explicit names:
 #' iris %>% mutate_if(is.numeric, list(scale = scale2, log = log))
+#' # ->
+#' iris %>%
+#'   as_tibble() %>%
+#'   mutate(across(where(is.numeric), list(scale = scale2, log = log)))
 #'
 #' # When there's only one function in the list, it modifies existing
 #' # variables in place. Give it a name to instead create new variables:
@@ -229,66 +250,72 @@ summarize_at <- summarise_at
 #' iris %>% mutate_if(is.numeric, list(scale = scale2))
 #' @export
 mutate_all <- function(.tbl, .funs, ...) {
+  lifecycle::signal_superseded("1.0.0", "mutate_all()", "across()")
   check_grouped(.tbl, "mutate", "all", alt = TRUE)
-  funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ...)
+  funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ..., .caller = "mutate_all")
   mutate(.tbl, !!!funs)
 }
 #' @rdname mutate_all
 #' @export
 mutate_if <- function(.tbl, .predicate, .funs, ...) {
+  lifecycle::signal_superseded("1.0.0", "mutate_if()", "across()")
   check_grouped(.tbl, "mutate", "if")
-  funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), ...)
+  funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), ..., .caller = "mutate_if")
   mutate(.tbl, !!!funs)
 }
 #' @rdname mutate_all
 #' @export
 mutate_at <- function(.tbl, .vars, .funs, ..., .cols = NULL) {
+  lifecycle::signal_superseded("1.0.0", "mutate_at()", "across()")
   .vars <- check_dot_cols(.vars, .cols)
-  funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), .include_group_vars = TRUE, ...)
+  funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), .include_group_vars = TRUE, ..., .caller = "mutate_at")
   mutate(.tbl, !!!funs)
 }
 
 #' @rdname mutate_all
 #' @export
 transmute_all <- function(.tbl, .funs, ...) {
+  lifecycle::signal_superseded("1.0.0", "transmute_all()", "across()")
   check_grouped(.tbl, "transmute", "all", alt = TRUE)
-  funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ...)
+  funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ..., .caller = "transmute_all")
   transmute(.tbl, !!!funs)
 }
 #' @rdname mutate_all
 #' @export
 transmute_if <- function(.tbl, .predicate, .funs, ...) {
+  lifecycle::signal_superseded("1.0.0", "transmute_if()", "across()")
   check_grouped(.tbl, "transmute", "if")
-  funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), ...)
+  funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), ..., .caller = "transmute_if")
   transmute(.tbl, !!!funs)
 }
 #' @rdname mutate_all
 #' @export
 transmute_at <- function(.tbl, .vars, .funs, ..., .cols = NULL) {
+  lifecycle::signal_superseded("1.0.0", "transmute_at()", "across()")
   .vars <- check_dot_cols(.vars, .cols)
-  funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), .include_group_vars = TRUE, ...)
+  funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), .include_group_vars = TRUE, ..., .caller = "transmute_at")
   transmute(.tbl, !!!funs)
 }
 
 # Helpers -----------------------------------------------------------------
 
-manip_all <- function(.tbl, .funs, .quo, .env, ..., .include_group_vars = FALSE) {
+manip_all <- function(.tbl, .funs, .quo, .env, ..., .include_group_vars = FALSE, .caller) {
   if (.include_group_vars) {
     syms <- syms(tbl_vars(.tbl))
   } else {
     syms <- syms(tbl_nongroup_vars(.tbl))
   }
-  funs <- as_fun_list(.funs, .env, ...)
+  funs <- as_fun_list(.funs, .env, ..., .caller = .caller)
   manip_apply_syms(funs, syms, .tbl)
 }
-manip_if <- function(.tbl, .predicate, .funs, .quo, .env, ..., .include_group_vars = FALSE) {
+manip_if <- function(.tbl, .predicate, .funs, .quo, .env, ..., .include_group_vars = FALSE, .caller) {
   vars <- tbl_if_syms(.tbl, .predicate, .env, .include_group_vars = .include_group_vars)
-  funs <- as_fun_list(.funs, .env, ...)
+  funs <- as_fun_list(.funs, .env, ..., .caller = .caller)
   manip_apply_syms(funs, vars, .tbl)
 }
-manip_at <- function(.tbl, .vars, .funs, .quo, .env, ..., .include_group_vars = FALSE) {
+manip_at <- function(.tbl, .vars, .funs, .quo, .env, ..., .include_group_vars = FALSE, .caller) {
   syms <- tbl_at_syms(.tbl, .vars, .include_group_vars = .include_group_vars)
-  funs <- as_fun_list(.funs, .env, ...)
+  funs <- as_fun_list(.funs, .env, ..., .caller = .caller)
   manip_apply_syms(funs, syms, .tbl)
 }
 
@@ -359,98 +386,6 @@ manip_apply_syms <- function(funs, syms, tbl) {
       names(out) <- paste(grid$var, grid$call, sep = "_")
     }
   }
+
   out
 }
-
-# Deprecated --------------------------------------------------------------
-
-#' Summarise and mutate multiple columns.
-#'
-#' \Sexpr[results=rd, stage=render]{dplyr:::lifecycle("deprecated")}
-#'
-#' @description
-#'
-#' `mutate_each()` and `summarise_each()` are deprecated in favour of
-#' a more featureful family of functions: [mutate_all()],
-#' [mutate_at()], [mutate_if()], [summarise_all()], [summarise_at()]
-#' and [summarise_if()].
-#'
-#' The `_each()` functions have two replacements depending on what
-#' variables you want to apply `funs` to. To apply a function to all
-#' variables, use [mutate_all()] or [summarise_all()]. To apply a
-#' function to a selection of variables, use [mutate_at()] or
-#' [summarise_at()].
-#'
-#' See the relevant section of `vignette("compatibility")` for more
-#' information.
-#'
-#' @keywords internal
-#' @export
-summarise_each <- function(tbl, funs, ...) {
-  summarise_each_(tbl, funs, enquos(...))
-}
-#' @export
-#' @rdname summarise_each
-summarise_each_ <- function(tbl, funs, vars) {
-  signal_soft_deprecated(paste_line(
-    "summarise_each() is deprecated",
-    "Please use summarise_if(), summarise_at(), or summarise_all() instead: ",
-    "",
-    "  - To map `funs` over all variables, use summarise_all()",
-    "  - To map `funs` over a selection of variables, use summarise_at()"
-  ))
-
-  if (is_empty(vars)) {
-    vars <- tbl_nongroup_vars(tbl)
-  } else {
-    vars <- compat_lazy_dots(vars, caller_env())
-    vars <- tidyselect::vars_select(tbl_nongroup_vars(tbl), !!!vars)
-    if (length(vars) == 1 && names(vars) == as_string(vars)) {
-      vars <- unname(vars)
-    }
-  }
-  if (is_character(funs)) {
-    funs <- funs_(funs)
-  }
-  funs <- manip_at(tbl, vars, funs, enquo(funs), caller_env())
-  summarise(tbl, !!!funs)
-}
-
-#' @export
-#' @rdname summarise_each
-mutate_each <- function(tbl, funs, ...) {
-  if (is_character(funs)) {
-    funs <- funs_(funs)
-  }
-
-  mutate_each_(tbl, funs, enquos(...))
-}
-#' @export
-#' @rdname summarise_each
-mutate_each_ <- function(tbl, funs, vars) {
-  signal_soft_deprecated(paste_line(
-    "mutate_each() is deprecated",
-    "Please use mutate_if(), mutate_at(), or mutate_all() instead: ",
-    "",
-    "  - To map `funs` over all variables, use mutate_all()",
-    "  - To map `funs` over a selection of variables, use mutate_at()"
-  ))
-  if (is_empty(vars)) {
-    vars <- tbl_nongroup_vars(tbl)
-  } else {
-    vars <- compat_lazy_dots(vars, caller_env())
-    vars <- tidyselect::vars_select(tbl_nongroup_vars(tbl), !!!vars)
-    if (length(vars) == 1 && names(vars) == as_string(vars)) {
-      vars <- unname(vars)
-    }
-  }
-  funs <- manip_at(tbl, vars, funs, enquo(funs), caller_env())
-  mutate(tbl, !!!funs)
-}
-
-#' @rdname summarise_each
-#' @export
-summarize_each <- summarise_each
-#' @rdname summarise_each
-#' @export
-summarize_each_ <- summarise_each_
