@@ -300,9 +300,7 @@ vec_split_id_order <- function(x) {
   split_id <- vec_group_loc(x)
   split_id$loc <- new_list_of(split_id$loc, ptype = integer())
 
-  # TODO: remove as.data.frame() once this is resolved
-  #       https://github.com/r-lib/vctrs/issues/1298
-  vec_slice(split_id, vec_order(as.data.frame(split_id$key)))
+  vec_slice(split_id, vec_order(split_id$key))
 }
 
 group_intersect <- function(x, new) {
